ifo_business: Return ifo business climate data
Description
Return ifo business climate data
Usage
ifo_business(
type = c("germany", "sectors", "eastern", "saxony"),
long_format = TRUE
)Value
A data.frame() containing the monthly ifo business climate time series.
Arguments
- type
character(1) Defaults to "germany". One of:
"germany": returns the ifo business climate index for Germany.
"sectors": returns the ifo business climate index for different sectors.
"eastern": returns the ifo business climate index for eastern Germany.
"saxony": returns the ifo business climate index for Saxony.
- long_format
logical(1) if TRUE return the data in long format.
Only applies to type "germany" and "sectors". Default TRUE.
See Also
The article for
a reproducible example.
Examples
Run this code# \donttest{
ifo_business("germany")
# }
Run the code above in your browser using DataLab